This function computes Whittle estimator for LS-ARMA and LS-ARFIMA models, in data with mean zero. If mean is not zero, then it is subtracted to data.
LS.whittle.loglik(
x,
series,
order = c(p = 0, q = 0),
ar.order = NULL,
ma.order = NULL,
sd.order = NULL,
d.order = NULL,
include.d = FALSE,
N = NULL,
S = NULL,
include.taper = TRUE
)(type: numeric) parameter vector.
(type: numeric) univariate time series.
(type: numeric) vector corresponding to ARMA model
entered.
(type: numeric) AR polimonial order.
(type: numeric) MA polimonial order.
(type: numeric) polinomial order noise scale factor.
(type: numeric) d polinomial order, where d is
the ARFIMA parameter.
(type: numeric) logical argument for ARFIMA models.
If include.d=FALSE then the model is an ARMA process.
(type: numeric) value corresponding to the length of the window to
compute periodogram. If N=NULL then the function will use
\(N = \textrm{trunc}(n^{0.8})\), see Dahlhaus (1998) where \(n\) is the
length of the y vector.
(type: numeric) value corresponding to the lag with which will go taking the blocks or windows.
(type: logical) logical argument that by default is
TRUE. See periodogram.
The estimation of the time-varying parameters can be carried out by means of the Whittle log-likelihood function proposed by Dahlhaus (1997), $$L_n(\theta) = \frac{1}{4\pi}\frac{1}{M} \int_{-\pi}^{\pi} \bigg\{log f_{\theta}(u_j,\lambda) + \frac{I_N(u_j, \lambda)}{f_{\theta}(u_j,\lambda)}\bigg\}\,d\lambda$$ where \(M\) is the number of blocks, \(N\) the length of the series per block, \(n =S(M-1)+N\), \(S\) is the shift from block to block, \(u_j =t_j/n\), \(t_j =S(j-1)+N/2\), \(j =1,\ldots,M\) and \(\lambda\) the Fourier frequencies in the block (\(2\,\pi\,k/N\), \(k = 1,\ldots, N\)).
For more information on theoretical foundations and estimation methods see brockwell2002introductionLSTS palma2010efficientLSTS